@@ -10,14 +10,9 @@ use LWP::Protocol::socks;
 use HTTP::Request::Common;
 use URI::Simple;
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0404';
 
-use constant {
-	HTTP_PROXY => 'http',
-	SOCKS4_PROXY => 'socks4',
-	SOCKS5_PROXY => 'socks',
-	HTTPS_PROXY => 'https',
-};
+my %PROXY_PROTOCOLS = (map { $_ => 1 } qw(http https socks socks4));
 
 sub new {
 	my ($self, %args) = @_;
@@ -26,59 +21,57 @@ sub new {
 	return $self;
 }
 
-# Get error message
-
+# Get/set error message
 sub error {
-	my ($self) = @_;
-	return ($self->{error}?$self->{error}:'N/A');
+	return shift->{error} || 'N/A';
+}
+
+sub _error {
+	my ( $self, $error_str ) = @_;
+	if ( $error_str ) {
+		$self->{error} = $error_str;
+	}
+
+	return $self->{error};
 }
 
 sub isError {
-	my ($self) = @_;
-	return ($self->{error}?1:0);
+	return shift->{error} ? 1 : 0;
 }
 
 # Set proxy
 sub setProxy {
 	my ($self, $proxyStr) = @_;
 
-	# If passed
-	if ($proxyStr) {
-
-		#  Get ip and port from it
-		#my ($protocol, $ip, $port) = $proxyStr =~ m#(\w+)://(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}):(\d{1,5})#;
-
-		my $proxyUrl = URI::Simple->new($proxyStr);
-		my ($protocol, $ip, $port) = ( $proxyUrl->protocol, $proxyUrl->host, ($proxyUrl->port || '80') );
-		#print "\n\$protocol=$protocol\n\$ip=$ip\n\$port=$port\n";
-
-		if ( defined($protocol) and defined($ip) and defined($port) ) {
-
-			unless ( $protocol eq HTTP_PROXY or $protocol eq HTTPS_PROXY or $protocol eq SOCKS4_PROXY or $protocol eq SOCKS5_PROXY ) {
-				$self->{error} = "Wrong protocol type [".$protocol."]";
-				return 0;
-			}
-
-			# Check the correctness of values
-			if ( $port <= 65535 ) {
-				$self->{proxy} = $protocol.'://'.$ip.':'.$port;
-				return 1;
-			} else {
-				$self->{error} = 'Error proxy format!';
-				return 0;
-			}
-
-		# Or return 0
-		} else {
-			$self->{proxy} =  'Wrong proxy protocol, ip or port!';
-			return 0;
-		}
-
-	} else {
-		# Or return 0
-		$self->{error} = 'Undefined proxy value!';
+	if ( !$proxyStr ) {
+		$self->_error('Undefined proxy value!');
 		return 0;
 	}
+
+	# If $proxyStr was passed, get protocol, ip and port from it
+	my $proxyUrl = URI::Simple->new($proxyStr);
+
+	# Check if we have protocol and host/ip from proxy string
+	if ( !$proxyUrl->protocol || !$proxyUrl->host ) {
+		$self->_error('Wrong proxy protocol or hostname!');
+		return 0;
+	}
+
+	# Check if protocol is correct
+	if ( ! exists($PROXY_PROTOCOLS{$proxyUrl->protocol})) {
+		$self->_error('Wrong protocol type: ' . $proxyUrl->protocol);
+		return 0;
+	}
+
+	# Check if port is correct
+	if ( $proxyUrl->port && $proxyUrl->port > 65535 ) {
+		$self->_error('Wrong proxy port!');
+		return 0;
+	}
+
+	$self->{proxy} = sprintf("%s://%s:%s", $proxyUrl->protocol, $proxyUrl->host, $proxyUrl->port || 80);
+
+	return 1;
 }
 
 # Assign ID
@@ -86,14 +79,14 @@ sub setId {
 	my ($self, $id) = @_;
 
 	# Check the length of ID
-	if ( defined($id) and $id =~ m#^\w+$# and length($id) <= 14 ) {
-		$self->{id} = $id;
-		return 1;
-	} else {
-		# Or return 0
-		$self->{error} = 'Wrong id syntax!';
+	if ( ! defined $id || $id !~ m#^\w{1,14}$# ) {
+		$self->_error('Wrong id syntax!');
 		return 0;
 	}
+
+	$self->{id} = $id;
+
+	return 1;
 }
 
 # Upload file
@@ -101,25 +94,23 @@ sub uploadFile {
 	my ($self, $filename) = @_;
 
 	# Assign ID unless already assigned
-	unless ($self->{id}) {
-		$self->{id} = time();
-	}
+	$self->{id} ||= time();
 
 	# Check if file path was passed
-	unless (defined $filename) {
-		$self->{error} = 'File parameter was not specified or is undef!';
+	if ( ! defined $filename ) {
+		$self->_error('File parameter was not specified or is undef!');
 		return 0;
 	}
 
 	# Check if it is a file
-	unless (-f $filename) {
-		$self->{error} = 'File parameter to uploadFile() was not found!';
+	if ( ! -f $filename ) {
+		$self->_error('File parameter to uploadFile() was not found!');
 		return 0;
 	}
 
 	# Check if file is readable
-	unless (-r $filename) {
-		$self->{error} = 'The file parameter to uploadFile() is not readable!';
+	if ( ! -r $filename) {
+		$self->error('The file parameter to uploadFile() is not readable!');
 		return 0;
 	}
 
@@ -140,13 +131,12 @@ sub uploadFile {
 
 	# Send POST-request and check the response
 	my $res = $self->{ua}->request($req);
-	if (my ($id) = ($res->content) =~ m#https://gyazo.com/(\w+)#is) {
+	if ( my ($id) = ($res->content) =~ m#https://gyazo.com/(\w+)#is ) {
 		return WebService::Gyazo::B::Image->new(id => $id);
 	} else {
-		$self->{error} = "Cannot parsed URL in the:\n".$res->as_string."\n";
+		$self->_error("Cannot parsed URL in the:\n".$res->as_string."\n");
 		return 0;
 	}
-
 }
 
 1;
@@ -161,7 +151,7 @@ WebService::Gyazo::B - a Perl image upload library for gyazo.com
 
 =head1 VERSION
 
-version 0.0403
+version 0.0404
 
 =head1 SYNOPSIS
 
